aboutsummaryrefslogtreecommitdiff
path: root/cast/sender/cast_app_discovery_service_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'cast/sender/cast_app_discovery_service_impl.h')
-rw-r--r--cast/sender/cast_app_discovery_service_impl.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/cast/sender/cast_app_discovery_service_impl.h b/cast/sender/cast_app_discovery_service_impl.h
index fa577808..49943994 100644
--- a/cast/sender/cast_app_discovery_service_impl.h
+++ b/cast/sender/cast_app_discovery_service_impl.h
@@ -9,7 +9,7 @@
#include <string>
#include <vector>
-#include "cast/common/public/service_info.h"
+#include "cast/common/public/receiver_info.h"
#include "cast/sender/cast_app_availability_tracker.h"
#include "cast/sender/cast_platform_client.h"
#include "cast/sender/public/cast_app_discovery_service.h"
@@ -33,12 +33,12 @@ class CastAppDiscoveryServiceImpl : public CastAppDiscoveryService {
const CastMediaSource& source,
AvailabilityCallback callback) override;
// Reissues app availability requests for currently registered (device_id,
// app_id) pairs whose status is kUnavailable or kUnknown.
void Refresh() override;
- void AddOrUpdateReceiver(const ServiceInfo& receiver);
- void RemoveReceiver(const ServiceInfo& receiver);
+ void AddOrUpdateReceiver(const ReceiverInfo& receiver);
+ void RemoveReceiver(const ReceiverInfo& receiver);
private:
struct AvailabilityCallbackEntry {
@@ -47,32 +47,32 @@ class CastAppDiscoveryServiceImpl : public CastAppDiscoveryService {
};
// Issues an app availability request for |app_id| to the receiver given by
- // |device_id|.
- void RequestAppAvailability(const std::string& device_id,
+ // |receiver_id|.
+ void RequestAppAvailability(const std::string& receiver_id,
const std::string& app_id);
- // Updates the availability result for |device_id| and |app_id| with |result|,
- // and notifies callbacks with updated availability query results.
- void UpdateAppAvailability(const std::string& device_id,
+ // Updates the availability result for |receiver_id| and |app_id| with
+ // |result|, and notifies callbacks with updated availability query results.
+ void UpdateAppAvailability(const std::string& receiver_id,
const std::string& app_id,
AppAvailabilityResult result);
// Updates the availability query results for |sources|.
void UpdateAvailabilityQueries(const std::vector<CastMediaSource>& sources);
- std::vector<ServiceInfo> GetReceiversByIds(
- const std::vector<std::string>& device_ids) const;
+ std::vector<ReceiverInfo> GetReceiversByIds(
+ const std::vector<std::string>& receiver_ids) const;
// Returns true if an app availability request should be issued for
// |device_id| and |app_id|. |now| is used for checking whether previously
// cached results should be refreshed.
- bool ShouldRefreshAppAvailability(const std::string& device_id,
+ bool ShouldRefreshAppAvailability(const std::string& receiver_id,
const std::string& app_id,
Clock::time_point now) const;
void RemoveAvailabilityCallback(uint32_t id) override;
- std::map<std::string, ServiceInfo> receivers_by_id_;
+ std::map<std::string, ReceiverInfo> receivers_by_id_;
// Registered availability queries and their associated callbacks keyed by
// media source IDs.
@@ -33,12 +33,12 @@ class CastAppDiscoveryServiceImpl : public CastAppDiscoveryService {
const CastMediaSource& source,
AvailabilityCallback callback) override;
- // Reissues app availability requests for currently registered (device_id,
+ // Reissues app availability requests for currently registered (receiver_id,
// app_id) pairs whose status is kUnavailable or kUnknown.
void Refresh() override;
@@ -47,32 +47,32 @@ class CastAppDiscoveryServiceImpl : public CastAppDiscoveryService {
// Returns true if an app availability request should be issued for
- // |device_id| and |app_id|. |now| is used for checking whether previously
+ // |receiver_id| and |app_id|. |now| is used for checking whether previously
// cached results should be refreshed.